---
title: '[공지] 결제내역 업데이트 오류 조치완료'
category: 공지사항
tags:
  - 공통
  - 공지사항
datetime: 2024-03-18T10:02:37.923Z
---

안녕하세요, 포트원 고객지원팀입니다.

금일 결제내역이 업데이트가 지연되는 이슈가 발생되었으며, 조치완료되어 안내드립니다.

- 이슈 발생시각 : 02/13 09시 02분\~ 12시15분 (조치완료)
- 현상 : 포트원 결제내역 내 거래조회(노출)되지 않음
- 참고사항 : 결제/취소 처리는 정상으로 이슈는 없었음.

이용에 불편을 드려 대단히 죄송합니다.

감사합니다.
